"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.activate = void 0;
const coc_nvim_1 = require("coc.nvim");
const autoClose_1 = require("./html/autoClose");
function activate(context) {
    var _a;
    const serverModule = require.resolve('svelte-language-server/bin/server.js');
    const runtimeConfig = coc_nvim_1.workspace.getConfiguration('svelte.language-server');
    const runExecArgv = [];
    let port = (_a = runtimeConfig.get('port')) !== null && _a !== void 0 ? _a : -1;
    if (port < 0) {
        port = 6009;
    }
    else {
        console.log('setting port to', port);
        runExecArgv.push(`--inspect=${port}`);
    }
    const debugOptions = { execArgv: ['--nolazy', `--inspect=${port}`] };
    const serverOptions = {
        run: {
            module: serverModule,
            transport: coc_nvim_1.TransportKind.ipc,
            options: { execArgv: runExecArgv },
        },
        debug: { module: serverModule, transport: coc_nvim_1.TransportKind.ipc, options: debugOptions },
    };
    const serverRuntime = runtimeConfig.get('runtime');
    if (serverRuntime) {
        serverOptions.run.runtime = serverRuntime;
        serverOptions.debug.runtime = serverRuntime;
        console.log('setting server runtime to', serverRuntime);
    }
    const clientOptions = {
        documentSelector: [{ scheme: 'file', language: 'svelte' }],
        revealOutputChannelOn: coc_nvim_1.RevealOutputChannelOn.Never,
        synchronize: {
            configurationSection: ['svelte'],
            fileEvents: coc_nvim_1.workspace.createFileSystemWatcher('{**/*.js,**/*.ts}', false, false, false),
        },
        initializationOptions: { config: coc_nvim_1.workspace.getConfiguration('svelte.plugin') },
    };
    let ls = createLanguageServer(serverOptions, clientOptions);
    context.subscriptions.push(ls.start());
    ls.onReady().then(() => {
        const tagRequestor = (document, position) => {
            const param = {
                textDocument: { uri: document.uri },
                position,
            };
            return ls.sendRequest('html/tag', param);
        };
        const disposable = autoClose_1.activateTagClosing(tagRequestor, { svelte: true }, 'html.autoClosingTags');
        context.subscriptions.push(disposable);
        coc_nvim_1.workspace.showMessage('Svelte language server now active.');
    });
    context.subscriptions.push(coc_nvim_1.commands.registerCommand('svelte.restartLanguageServer', async () => {
        await ls.stop();
        ls = createLanguageServer(serverOptions, clientOptions);
        context.subscriptions.push(ls.start());
        await ls.onReady();
        coc_nvim_1.workspace.showMessage('Svelte language server restarted.');
    }));
}
exports.activate = activate;
function createLanguageServer(serverOptions, clientOptions) {
    return new coc_nvim_1.LanguageClient('svelte', 'Svelte', serverOptions, clientOptions);
}
//# sourceMappingURL=extension.js.map